Namib is a list containing the following 6 items:DZ: a distributional dataset containing the zircon
U-Pb ages for ca. 100 grains from each sample, as well as their
(1-sigma) analytical uncertainties.
PT: a compositional dataset with the bulk petrography
of the samples, i.e. the quartz ('Q'), K-feldspar ('KF'),
plagioclase ('P'), and lithic fragments of metamorphic ('Lm'),
volcanic ('Lv') and sedimentary ('Ls') origin.
HM: a compositional dataset containing the heavy
mineral composition of the samples, comprised of zircon ('zr'),
tourmaline ('tm'), rutile ('rt'), Ti-oxides ('TiOx'), titanite
('sph'), apatite ('ap'), epidote ('ep'), garnet ('gt'), staurolite
('st'), andalusite ('and'), kyanite ('ky'), sillimanite ('sil'),
amphibole ('amp'), clinopyroxene ('cpx') and orthopyroxene ('opx').
PTHM: a compositional dataset combining the variables
contained in PT and HM plus 'mica', 'opaques',
'turbids' and 'other' transparent heavy minerals ('LgM'),
normalised to 100.
Major: a compositional dataset listing the
concentrations (in wtTiO2, P2O5 and MnO.
Trace: a compositional data listing the concentrations
(in ppm) of Rb, Sr, Ba, Sc, Y, La, Ce, Pr, Nd, Sm, Gd, Dy, Er, Yb, Th,
U, Zr, Hf, V, Nb, Cr, Co, Ni, Cu, Zn, Ga and Pb.
data(Namib)
samp <- Namib$DZ$x[['N1']]
dens <- KDE(samp,0,3000)
plot(dens)Run the code above in your browser using DataLab