Learn R Programming

provenance (version 1.5)

indscal: Individual Differences Scaling of provenance data

Description

Performs 3-way Multidimensional Scaling analysis using Carroll and Chang (1970)'s INdividual Differences SCALing method as implemented using De Leeuw and Mair (2011)'s stress majorization algorithm.

Usage

indscal(..., type = "ordinal")

Arguments

...
a sequence of datasets of class distributional or compositional
type
is either "ratio" or "ordinal"

Value

an object of class INDSCAL, i.e. a list containing the following items:delta: Observed dissimilaritiesobsdiss: List of observed dissimilarities, normalizedconfdiss: List of configuration dissimilaritiesconf: List of matrices of final configurationsgspace: Joint configurations aka group stimulus spacecweights: Configuration weightsstress: Stress-1 valuespp: Stress per pointsps: Stress per subject (matrix)ndim: Number of dimensionsmodel: Type of smacof modelniter: Number of iterationsnobj: Number of objects

References

de Leeuw, J., & Mair, P. (2009). Multidimensional scaling using majorization: The R package smacof. Journal of Statistical Software, 31(3), 1-30, < http://www.jstatsoft.org/v31/i03/>

Examples

Run this code
data(Namib)
plot(indscal(Namib$DZ,Namib$HM))

Run the code above in your browser using DataLab