Arguments
fname
the path of a .csv file with the input data,
arranged in columns.
errorfile
the (optional) path of a .csv file with the
standard errors of the input data, arranged by column in the same
order as fname. Must be specified if the data are to be
compared with the Sircombe-Hazelton dissimilarity.
method
an optional string specifying the dissimilarity
measure which should be used for comparing this with other
datasets. Should be one of either "KS" (for
Kolmogorov-Smirnov) or "SH" (for Sircombe and Hazelton). If
method = "SH", then errorfile should be specified. If
method = "SH" and errorfile is unspecified, then the
program will default back to the Kolmogorov-Smirnov dissimilarity.
xlab
an optional string specifying the nature and units of
the data. This string is used to label kernel density estimates.
colmap
an optional string with the name of one of R's
built-in colour palettes (e.g., heat.colors, terrain.colors,
topo.colors, cm.colors), which are to be used for plotting the data.