Learn R Programming

provenance (version 1.3)

KDEs: Generate an object of class KDEs

Description

Convert a dataset of class distributional into an object of class KDEs for further processing by the summaryplot function.

Usage

KDEs(x, from = NA, to = NA, bw = NA, samebandwidth = TRUE,
  adaptive = TRUE, pch = NA, normalise = FALSE, log = FALSE, ...)

Arguments

x
an object of class distributional
from
minimum limit of the x-axis.
to
maximum limit of the x-axis.
bw
the bandwidth of the kernel density estimates. If bw = NA, the bandwidth will be set automatically using botev()
samebandwidth
boolean flag indicating whether the same bandwidth should be used for all samples. If samebandwidth = TRUE and bw = NULL, then the function will use the median bandwidth of all the samples.
adaptive
boolean flag switching on the adaptive bandwidth modifier of Abramson (1982)
pch
(optional) symbol to be used to mark the sample points along the x-axis
normalise
boolean flag indicating whether or not the KDEs should all integrate to the same value.
log
boolean flag indicating whether the data should by plotted on a logarithmic scale.
...
optional parameters to be passed on to density

Value

  • an object of class KDEs, i.e. a list containing the following items:

    kdes: a named list with objects of class KDE

    from: the beginning of the common time scale

    to: the end of the common time scale

    themax: the maximum probability density of all the KDEs

    pch: the plot symbol to be used by plot.KDEs

    xlabel: the x-axis label to be used by plot.KDEs

See Also

KDE

Examples

Run this code
data(Namib)
KDEs <- KDEs(Namib$DZ,0,3000,pch=NA)
summaryplot(KDEs,ncol=3)

Run the code above in your browser using DataLab